@@ -31,9 +31,7 @@ edit_r_environ <- function(scope = c("user", "project")) {
 #' @export
 #' @rdname edit
 edit_r_makevars <- function(scope = c("user", "project")) {
-  dir <- scope_dir(scope)
-  create_directory(dir, ".R")
-  edit_file(dir, ".R/Makevars")
+  edit_file(scope_dir(scope), ".R/Makevars")
   todo("Restart R for changes to take effect")
   invisible()
 }
@@ -42,19 +40,16 @@ edit_r_makevars <- function(scope = c("user", "project")) {
 #' @rdname edit
 edit_git_config <- function(scope = c("user", "project")) {
   scope <- match.arg(scope)
-  switch(scope,
-    user = edit_file("~", ".gitconfig"),
-    project = edit_file(proj_get(), ".git/config")
-  )
-
+  path <- switch(scope, user = ".gitconfig", project = ".git/config")
+  edit_file(git_scope_dir(scope), path = path)
   invisible()
 }
 
 #' @export
 #' @rdname edit
 edit_git_ignore <- function(scope = c("user", "project")) {
-  scope <- match.arg(scope)
-  edit_file(scope_dir(scope), ".gitignore")
+  ## TODO(jennybc) https://github.com/r-lib/usethis/issues/182
+  edit_file(git_scope_dir(scope), ".gitignore")
   invisible()
 }
 
@@ -69,7 +64,22 @@ edit_rstudio_snippets <- function(type = "R") {
 
 scope_dir <- function(scope = c("user", "project")) {
   scope <- match.arg(scope)
-  message("Editing in ", scope, " scope")
+  message("Editing in ", field(scope), " scope")
 
   switch(scope, user = path.expand("~"), project = proj_get())
 }
+
+git_scope_dir <- function(scope = c("user", "project")) {
+  scope <- match.arg(scope)
+  message("Editing in git ", field(scope), " scope")
+
+  switch(scope, user = git_user_dot_home(), project = proj_get())
+}
+
+git_user_dot_home <- function() {
+  if (.Platform$OS.type == "windows") {
+    Sys.getenv("USERPROFILE")
+  } else {
+    path.expand("~")
+  }
+}
