@@ -1,8 +1,9 @@
 #' Connect a local repo with GitHub.
 #'
-#' `use_github` calls [use_git()] if needed, creates
-#' repo on github, then sets up appropriate git remotes and syncs.
-#' `use_github_links` populates the `URL` and `BugReports`
+#' `use_github()` requires that your package have a git repository,
+#' which you can create with [use_git()], if needed.
+#' `use_github()` then sets up appropriate git remotes and syncs.
+#' `use_github_links()` populates the `URL` and `BugReports`
 #' fields with appropriate links (unless they already exist).
 #'
 #' @section Authentication:
@@ -46,13 +47,14 @@
 #' @export
 #' @examples
 #' \dontrun{
-#' ## to use default ssh protocol
-#' create("testpkg")
-#' use_github(pkg = "testpkg")
+#' create_package("test-pkg") # creates package in current working directory
 #'
-#' ## or use https
-#' create("testpkg2")
-#' use_github(pkg = "testpkg2", protocol = "https")
+#' ## now, working inside "test-pkg", initialize git repository
+#' use_git()
+#'
+#' ## create github repository and configure as git remote
+#' use_github()                   ## to use default ssh protocol
+#' use_github(protocol = "https") ## to use https
 #' }
 use_github <- function(organisation = NULL,
                        private = FALSE,
@@ -60,9 +62,11 @@ use_github <- function(organisation = NULL,
                        credentials = NULL,
                        auth_token = NULL,
                        host = NULL) {
-
   if (!uses_git()) {
-    stop("Please use_git() before use_github()", call. = FALSE)
+    stop(
+      "Please call ", code("use_git()"), " before ",
+      code("use_github()"), ".", call. = FALSE
+    )
   }
 
   if (uses_github(proj_get())) {
@@ -74,20 +78,30 @@ use_github <- function(organisation = NULL,
   repo_name <- pkg$Project %||% gsub("\n", " ", pkg$Package)
   repo_desc <- pkg$Title %||% ""
 
-  todo("Check title and description")
-  code_block(
-    paste0("Name:        ", repo_name),
-    paste0("Description: ", repo_desc),
-    copy = FALSE
-  )
-  if (yesno("Are title and description ok?")) {
-    return(invisible())
+  if (interactive()) {
+    todo("Check title and description")
+    code_block(
+      paste0("Name:        ", repo_name),
+      paste0("Description: ", repo_desc),
+      copy = FALSE
+    )
+    if (nope("Are title and description ok?")) {
+      return(invisible())
+    }
+  } else {
+    done("Setting title and description")
+    code_block(
+      paste0("Name:        ", repo_name),
+      paste0("Description: ", repo_desc),
+      copy = FALSE
+    )
   }
 
   done("Creating GitHub repository")
 
   if (is.null(organisation)) {
-    create <- gh::gh("POST /user/repos",
+    create <- gh::gh(
+      "POST /user/repos",
       name = repo_name,
       description = repo_desc,
       private = private,
@@ -95,7 +109,8 @@ use_github <- function(organisation = NULL,
       .token = auth_token
     )
   } else {
-    create <- gh::gh("POST /orgs/:org/repos",
+    create <- gh::gh(
+      "POST /orgs/:org/repos",
       org = organisation,
       name = repo_name,
       description = repo_desc,
@@ -145,7 +160,6 @@ use_github <- function(organisation = NULL,
 #' @rdname use_github
 use_github_links <- function(auth_token = NULL,
                              host = "https://api.github.com") {
-
   check_uses_github()
 
   info <- gh::gh_tree_remote(proj_get())
