@@ -6,8 +6,9 @@
 #'
 #' @export
 use_pkgdown <- function() {
+  check_is_package("use_pkgdown()")
   edit_file(proj_get(), "_pkgdown.yml")
   use_build_ignore("_pkgdown.yml")
 
-  use_directory("doc", ignore = TRUE)
+  use_directory("docs", ignore = TRUE)
 }
