@@ -2,12 +2,12 @@
 #'
 #' These helpers follow tidyverse conventions which are generally a little
 #' stricter than the defaults, reflecting the need for greater rigor in
-#' commonly used packages
+#' commonly used packages.
 #'
 #' @details
 #'
 #' * `use_tidy_ci()`: sets up travis and codecov, ensuring that the package
-#'    works on all version of R starting at 3.1.
+#'    works on all versions of R starting at 3.1.
 #'
 #' * `use_tidy_description()`: puts fields in standard order and alphabetises
 #'   dependencies.
@@ -18,10 +18,18 @@
 #' * `use_tidy_versions()`: pins all dependencies to require at least
 #'   the currently installed version.
 #'
-#' @md
+#' * `use_tidy_contributing()`: creates tidyverse contributing guidelines from
+#'    tidy_contributing template.
+#'
+#' * `use_tidy_issue_template()`: creates a standard tidyverse issue template.
+#'
+#' * `use_tidy_support()`: creates support resources document for GitHub repo
+#'    using SUPPORT.md.
+#'
 #' @name tidyverse
 NULL
 
+
 #' @export
 #' @rdname tidyverse
 #' @inheritParams use_travis
@@ -62,8 +70,9 @@ use_tidy_description <- function() {
 
   # Alphabetise remotes
   remotes <- desc::desc_get_remotes(file = base_path)
-  if (length(remotes) > 0)
+  if (length(remotes) > 0) {
     desc::desc_set_remotes(sort(remotes), file = base_path)
+  }
 
   # Reorder all fields
   desc::desc_reorder_fields(file = base_path)
@@ -110,3 +119,51 @@ use_tidy_eval <- function() {
 
   todo("Run document()")
 }
+
+
+#' @export
+#' @rdname tidyverse
+use_tidy_contributing <- function() {
+  check_uses_travis()
+
+  gh <- gh::gh_tree_remote(proj_get())
+  travis_url <- file.path("https://travis-ci.org", gh$username, gh$repo)
+  github_url <- file.path("https://github.com", gh$username, gh$repo)
+
+  use_template(
+    "tidy_contributing.md",
+    "CONTRIBUTING.md",
+    data = list(
+      package = project_name(),
+      github_url = github_url,
+      travis_url = travis_url
+    ),
+    ignore = TRUE
+  )
+}
+
+
+#' @export
+#' @rdname tidyverse
+use_tidy_issue_template <- function() {
+  check_uses_github()
+
+  use_template(
+    "ISSUE_TEMPLATE.md",
+    "ISSUE_TEMPLATE.md",
+    ignore = TRUE
+  )
+}
+
+
+#' @export
+#' @rdname tidyverse
+use_tidy_support <- function() {
+  check_uses_github()
+
+  use_template(
+    "SUPPORT.md",
+    data = list(package = project_name()),
+    ignore = TRUE
+  )
+}
